@@ -2,7 +2,7 @@ package Test2::AsyncSubtest::Hub;
 use strict;
 use warnings;
 
-our $VERSION = '0.000016';
+our $VERSION = '0.000018';
 
 use base 'Test2::Hub::Subtest';
 use Test2::Util::HashBase qw/ast_ids/;
@@ -26,6 +26,10 @@ sub inherit {
         push @{$self->{+_LISTENERS}} => grep { $_->{inherit} } @$ls;
     }
 
+    if (my $pfs = $from->{+_PRE_FILTERS}) {
+        push @{$self->{+_PRE_FILTERS}} => grep { $_->{inherit} } @$pfs;
+    }
+
     if (my $fs = $from->{+_FILTERS}) {
         push @{$self->{+_FILTERS}} => grep { $_->{inherit} } @$fs;
     }
